@@ -11,13 +11,14 @@ argo_search <- function(func = NULL, of = NULL, qwmo = NULL, wmo = NULL, box=NUL
                         pres_qc = NULL, temp_qc = NULL, psal_qc = NULL, doxy_qc = NULL, 
                         ticket = NULL, limit = 10, ...) {
   
-  args <- noaa_compact(list(get = func, of = of, qwmo = qwmo, wmo = wmo, file = file, 
+  if (!is.null(box)) box <- paste0(box, collapse = ",")
+  args <- noaa_compact(list(get = func, of = of, qwmo = qwmo, wmo = wmo,
       box = box, area = area, around = around, year = year, yearmin = yearmin, 
       yearmax = yearmax, month = month, monthmin = monthmin, monthmax = monthmax,
       lr = lr, from = from, to = to, dmode = dmode, pres_qc = pres_qc, temp_qc = temp_qc, 
       psal_qc = psal_qc, doxy_qc = doxy_qc, ticket = ticket, limit = limit))
-  res <- argo_GET(argo_api(), args, ...)
-  jsonlite::fromJSON(content(res, "text"))
+  res <- argo_GET(url = argo_api(), args, ...)
+  jsonlite::fromJSON(utcf8(res))
 }
 
 #' @export
@@ -25,7 +26,7 @@ argo_search <- function(func = NULL, of = NULL, qwmo = NULL, wmo = NULL, box=NUL
 argo_files <- function(wmo = NULL, cyc = NULL, ...) {
   args <- noaa_compact(list(wmo = wmo, cyc = cyc, file = ""))
   res <- argo_GET(argo_api(), args, ...)
-  jsonlite::fromJSON(content(res, "text"))
+  jsonlite::fromJSON(utcf8(res))
 }
 
 #' @export
@@ -33,7 +34,7 @@ argo_files <- function(wmo = NULL, cyc = NULL, ...) {
 argo_qwmo <- function(qwmo, limit = 10, ...) {
   args <- noaa_compact(list(qwmo = qwmo, limit = limit))
   res <- argo_GET(argo_api(), args, ...)
-  jsonlite::fromJSON(content(res, "text"))
+  jsonlite::fromJSON(utcf8(res))
 }
 
 #' @export
@@ -41,7 +42,7 @@ argo_qwmo <- function(qwmo, limit = 10, ...) {
 argo_plan <- function(...) {
   args <- noaa_compact(list(plan = ""))
   res <- argo_GET(argo_api(), args, ...)
-  jsonlite::fromJSON(content(res, "text"))
+  jsonlite::fromJSON(utcf8(res))
 }
 
 #' @export
