@@ -8,6 +8,9 @@
 #' @template rnoaa
 #' @template rnoaa2
 #' @template datasets
+#' @param datasetid (optional) Accepts a single valid dataset id. Data returned will be 
+#'    from the dataset specified.
+#' @param stationid Accepts a valid station id or a vector or list of station ids
 #' @return A data.frame for all datasets, or a list of length two, each with a data.frame.
 #' @examples \dontrun{
 #' # Get a table of all datasets
@@ -18,14 +21,21 @@
 #'
 #' # Get datasets with Temperature at the time of observation (TOBS) data type
 #' ncdc_datasets(datatypeid='TOBS')
+#' ## two datatypeid's
+#' ncdc_datasets(datatypeid=c('TOBS', "ACMH"))
 #'
 #' # Get datasets with data for a series of the same parameter arg, in this case
 #' # stationid's
+#' ncdc_datasets(stationid='COOP:310090')
 #' ncdc_datasets(stationid=c('COOP:310090','COOP:310184','COOP:310212'))
 #'
 #' # Multiple datatypeid's
 #' ncdc_datasets(datatypeid=c('ACMC','ACMH','ACSC'))
 #' ncdc_datasets(datasetid='ANNUAL', datatypeid=c('ACMC','ACMH','ACSC'))
+#' 
+#' # Multiple locationid's
+#' ncdc_datasets(locationid="FIPS:30091")
+#' ncdc_datasets(locationid=c("FIPS:30103", "FIPS:30091"))
 #' }
 
 ncdc_datasets <- function(datasetid=NULL, datatypeid=NULL, stationid=NULL, locationid=NULL,
@@ -34,34 +44,41 @@ ncdc_datasets <- function(datasetid=NULL, datatypeid=NULL, stationid=NULL, locat
 {
   calls <- names(sapply(match.call(), deparse))[-1]
   calls_vec <- c("dataset", "page", "year", "month") %in% calls
-  if(any(calls_vec))
+  if (any(calls_vec))
     stop("The parameters dataset, page, year, and month \n  have been removed, and were only relavant in the old NOAA API v1. \n\nPlease see documentation for ?ncdc_datasets")
 
   token <- check_key(token)
 
   url <- "http://www.ncdc.noaa.gov/cdo-web/api/v2/datasets"
-  if(!is.null(datasetid))
-    url <- paste(url, "/", datasetid, sep="")
-  args <- noaa_compact(list(datatypeid=datatypeid,
-                       locationid=locationid, stationid=stationid, startdate=startdate,
+  if (!is.null(datasetid)) url <- paste(url, "/", datasetid, sep = "")
+  args <- noaa_compact(list(startdate=startdate,
                        enddate=enddate, sortfield=sortfield, sortorder=sortorder,
                        limit=limit, offset=offset))
+  if (!is.null(stationid)) {
+    stationid <- lapply(stationid, function(x) list(stationid = x))
+  }
+  if (!is.null(datatypeid)) {
+    datatypeid <- lapply(datatypeid, function(x) list(datatypeid = x))
+  }
+  if (!is.null(locationid)) {
+    locationid <- lapply(locationid, function(x) list(locationid = x))
+  }
+  args <- c(args, stationid, datatypeid, locationid)
   args <- as.list(unlist(args))
   names(args) <- gsub("[0-9]+", "", names(args))
   if (length(args) == 0) args <- NULL
-  temp <- GET(url, query=args, add_headers("token" = token), ...)
+  temp <- GET(url, query = args, add_headers("token" = token), ...)
   tt <- check_response(temp)
-  if(is(tt, "character")){
-    all <- list(meta=NULL, data=NULL)
+  if (is(tt, "character")) {
+    all <- list(meta = NULL, data = NULL)
   } else {
-    if(!is.null(datasetid)){
-      dat <- data.frame(tt, stringsAsFactors=FALSE)
+    if (!is.null(datasetid)) {
+      dat <- data.frame(tt, stringsAsFactors = FALSE)
       all <- list(meta = NULL, data = dat)
-    } else
-    {
-      dat <- dplyr::bind_rows(lapply(tt$results, function(x) data.frame(x, stringsAsFactors=FALSE)))
+    } else {
+      dat <- dplyr::bind_rows(lapply(tt$results, function(x) data.frame(x, stringsAsFactors = FALSE)))
       all <- list(meta = tt$metadata$resultset, data = dat)
     }
   }
-  structure(all, class="ncdc_datasets")
+  structure(all, class = "ncdc_datasets")
 }
