@@ -1,18 +1,17 @@
 #' Plot NOAA climate data.
 #'
-#' This function accepts directly output from the \code{\link[rnoaa]{ncdc}} function,
-#' not other functions.
-#'
 #' @export
-#'
 #' @param ... Input noaa object or objects.
-#' @param breaks Regularly spaced date breaks for x-axis. See examples for usage. 
-#' See \code{\link{date_breaks}}. Default: \code{NULL} (uses ggplot2 default break 
+#' @param breaks Regularly spaced date breaks for x-axis. See examples for usage.
+#' See \code{\link{date_breaks}}. Default: \code{NULL} (uses ggplot2 default break
 #' sformatting)
 #' @param dateformat Date format using standard POSIX specification for labels on
 #' x-axis. See \code{\link{date_format}}
 #' @return ggplot2 plot
 #' @details
+#' This function accepts directly output from the \code{\link[rnoaa]{ncdc}} function,
+#' not other functions.
+#'
 #' This is a simple wrapper function around some ggplot2 code. There is indeed a lot you
 #' can modify in your plots, so this function just does some basic stuff. Look at the internals
 #' for what the function does.
@@ -26,10 +25,6 @@
 #' ncdc_plot(out, breaks="1 month", dateformat="%d/%m")
 #' ncdc_plot(out, breaks="1 month", dateformat="%d/%m")
 #'
-#' out2 <- ncdc(datasetid='GHCND', stationid='GHCND:USW00014895', datatypeid='PRCP',
-#'    startdate = '2010-05-01', enddate = '2010-05-03', limit=100)
-#' ncdc_plot(out2, breaks="6 hours", dateformat="%H")
-#'
 #' # Combine many calls to ncdc function
 #' out1 <- ncdc(datasetid='GHCND', stationid='GHCND:USW00014895', datatypeid='PRCP',
 #'    startdate = '2010-03-01', enddate = '2010-05-31', limit=500)
@@ -81,7 +76,8 @@ plot_template <- function(df, breaks, dateformat) {
     labs(y = as.character(df[1, 'datatype']), x = "Date")
   )
   if (!is.null(breaks)) {
-    c(tt, scale_x_datetime(breaks = date_breaks(breaks), labels = date_format(dateformat)))
+    c(tt, scale_x_date(date_breaks = breaks, date_labels = dateformat))
+
   } else {
     tt
   }
