@@ -10,6 +10,7 @@
 #' @param what (character) One of storm_columns or storm_names.
 #' @param type (character) One of points or lines. This gives shp files with points, or with lines.
 #' @param x Output from \code{storm_shp}, a path to shp file to read in.
+#' @param ... Curl options passed on to \code{\link[httr]{GET}} (optional)
 #'
 #' @details International Best Track Archive for Climate Stewardship (IBTrACS)
 #'
@@ -28,8 +29,8 @@
 #'
 #' See \url{http://www.ncdc.noaa.gov/ibtracs/index.php?name=numbering} for more.
 #'
-#' The datasets included in the package \code{\link[rnoaa]{storm_names}}, and
-#' \code{\link[rnoaa]{storm_columns}} may help in using these storm functions.
+#' The datasets included in the package \code{\link{storm_names}}, and
+#' \code{\link{storm_columns}} may help in using these storm functions.
 #'
 #' @references \url{http://www.ncdc.noaa.gov/ibtracs/index.php?name=wmo-data}
 #'
@@ -48,10 +49,6 @@
 #' storm_data(year=1941)
 #' storm_data(year=2010)
 #'
-#' ## Or get all data, simply don't specify a value for basin, storm, or year
-#' res <- storm_data(read=FALSE) # just get path
-#' head()
-#'
 #' # shp files
 #' ## storm_shp downloads data and gives a path back
 #' ## to read in, use storm_shp_read
@@ -71,7 +68,7 @@
 #'
 #' ### for year 1940, lines
 #' (res3_lines <- storm_shp(year=1940, type="lines"))
-#' res3_linesshp <- storm_shp_read(res3_lines)
+#' res3_linesshp <- storm_shp_read(x=res3_lines)
 #' plot(res3_linesshp)
 #'
 #' ### for year 2010, points
@@ -81,14 +78,14 @@
 #' }
 
 storm_data <- function(basin=NULL, storm=NULL, year=NULL, path="~/.rnoaa/storms",
-                       overwrite = TRUE){
+                       overwrite = TRUE, ...){
 
   csvpath <- csv_local(basin, storm, year, path)
-  if(!is_storm(x = csvpath)){
-    csvpath <- storm_GET(path, basin, storm, year, overwrite)
+  if (!is_storm(x = csvpath)) {
+    csvpath <- storm_GET(path, basin, storm, year, overwrite, ...)
   }
   message(sprintf("<path>%s", csvpath), "\n")
-  structure(list(data=read_csv(csvpath)), class="storm_data")
+  structure(list(data = read_csv(csvpath)), class = "storm_data")
 }
 
 #' @export
@@ -98,17 +95,17 @@ print.storm_data <- function(x, ..., n = 10){
   trunc_mat_(x$data, n = n)
 }
 
-storm_GET <- function(bp, basin, storm, year, overwrite){
+storm_GET <- function(bp, basin, storm, year, overwrite, ...){
   dir.create(local_base(basin, storm, year, bp), showWarnings = FALSE, recursive = TRUE)
   fp <- csv_local(basin, storm, year, bp)
-  res <- suppressWarnings(GET(csv_remote(basin, storm, year), write_disk(fp, overwrite)))
-  res$request$writer[[1]]
+  res <- suppressWarnings(GET(csv_remote(basin, storm, year), write_disk(fp, overwrite), ...))
+  res$request$output$path
 }
 
 filecheck <- function(basin, storm, year){
-  tmp <- noaa_compact(list(basin=basin, storm=storm, year=year))
-  if(length(tmp) > 1) stop("You can only supply one or more of basin, storm, or year")
-  if(length(tmp) == 0) list(all="Allstorms") else tmp
+  tmp <- noaa_compact(list(basin = basin, storm = storm, year = year))
+  if (length(tmp) > 1) stop("You can only supply one or more of basin, storm, or year")
+  if (length(tmp) == 0) list(all = "Allstorms") else tmp
 }
 
 filepath <- function(basin, storm, year){
@@ -123,7 +120,7 @@ filepath <- function(basin, storm, year){
 
 fileext <- function(basin, storm, year){
   tt <- filepath(basin, storm, year)
-  if(grepl("Allstorms", tt)) paste0(tt, '.ibtracs_all.v03r06.csv.gz') else paste0(tt, '.ibtracs_all.v03r06.csv')
+  if (grepl("Allstorms", tt)) paste0(tt, '.ibtracs_all.v03r06.csv.gz') else paste0(tt, '.ibtracs_all.v03r06.csv')
 }
 
 csv_remote <- function(basin, storm, year) file.path(stormurl(), fileext(basin, storm, year))
@@ -131,9 +128,9 @@ csv_local <- function(basin, storm, year, path) file.path(path, fileext(basin, s
 
 local_base <- function(basin, storm, year, path){
   tt <- filecheck(basin, storm, year)
-  if(names(tt)=="all") path else file.path(path, names(tt))
+  if (names(tt) == "all") path else file.path(path, names(tt))
 }
 
-is_storm <- function(x) if(file.exists(x)) TRUE else FALSE
+is_storm <- function(x) if (file.exists(x)) TRUE else FALSE
 
 stormurl <- function(x = "csv") sprintf('ftp://eclipse.ncdc.noaa.gov/pub/ibtracs/v03r06/all/%s', x)
